==> kubernetes-model-gatewayapi-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ListenerFluent<A extends ListenerFluent<A>> extends BaseFluent<A>{
  public ListenerFluent() {
  }
  public ListenerFluent(Listener instance) {
    instance = (instance != null ? instance : new Listener());

    if (instance != null) {
      this.withAllowedRoutes(instance.getAllowedRoutes());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTls(instance.getTls());
      this.withAllowedRoutes(instance.getAllowedRoutes());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTls(instance.getTls());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private AllowedRoutesBuilder allowedRoutes;
  private String hostname;
  private String name;
  private Integer port;
  private String protocol;
  private GatewayTLSConfigBuilder tls;
  private Map<String,Object> additionalProperties;
  public AllowedRoutes buildAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  public A withAllowedRoutes(AllowedRoutes allowedRoutes) {
    _visitables.get("allowedRoutes").remove(this.allowedRoutes);
    if (allowedRoutes!=null){ this.allowedRoutes= new AllowedRoutesBuilder(allowedRoutes); _visitables.get("allowedRoutes").add(this.allowedRoutes);} else { this.allowedRoutes = null; _visitables.get("allowedRoutes").remove(this.allowedRoutes); } return (A) this;
  }
  public boolean hasAllowedRoutes() {
    return this.allowedRoutes != null;
  }
  public AllowedRoutesNested<A> withNewAllowedRoutes() {
    return new AllowedRoutesNested(null);
  }
  public AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item) {
    return new AllowedRoutesNested(item);
  }
  public AllowedRoutesNested<A> editAllowedRoutes() {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(null));
  }
  public AllowedRoutesNested<A> editOrNewAllowedRoutes() {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(new AllowedRoutesBuilder().build()));
  }
  public AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item) {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(item));
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  public GatewayTLSConfig buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public A withTls(GatewayTLSConfig tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new GatewayTLSConfigBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  public boolean hasTls() {
    return this.tls != null;
  }
  public TlsNested<A> withNewTls() {
    return new TlsNested(null);
  }
  public TlsNested<A> withNewTlsLike(GatewayTLSConfig item) {
    return new TlsNested(item);
  }
  public TlsNested<A> editTls() {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(null));
  }
  public TlsNested<A> editOrNewTls() {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(new GatewayTLSConfigBuilder().build()));
  }
  public TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item) {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ListenerFluent that = (ListenerFluent) o;
    if (!java.util.Objects.equals(allowedRoutes, that.allowedRoutes)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(protocol, that.protocol)) return false;

    if (!java.util.Objects.equals(tls, that.tls)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedRoutes,  hostname,  name,  port,  protocol,  tls,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedRoutes != null) { sb.append("allowedRoutes:"); sb.append(allowedRoutes + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AllowedRoutesNested<N> extends AllowedRoutesFluent<AllowedRoutesNested<N>> implements Nested<N>{
    AllowedRoutesNested(AllowedRoutes item) {
      this.builder = new AllowedRoutesBuilder(this, item);
    }
    AllowedRoutesBuilder builder;
    public N and() {
      return (N) ListenerFluent.this.withAllowedRoutes(builder.build());
    }
    public N endAllowedRoutes() {
      return and();
    }
    
  }
  public class TlsNested<N> extends GatewayTLSConfigFluent<TlsNested<N>> implements Nested<N>{
    TlsNested(GatewayTLSConfig item) {
      this.builder = new GatewayTLSConfigBuilder(this, item);
    }
    GatewayTLSConfigBuilder builder;
    public N and() {
      return (N) ListenerFluent.this.withTls(builder.build());
    }
    public N endTls() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ListenerFluent<A extends ListenerFluent<A>> extends BaseFluent<A>{
  public ListenerFluent() {
  }
  
  public ListenerFluent(Listener instance) {
    this.copyInstance(instance);
  }
  private AllowedRoutesBuilder allowedRoutes;
  private String hostname;
  private String name;
  private Integer port;
  private String protocol;
  private GatewayTLSConfigBuilder tls;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Listener instance) {
    instance = (instance != null ? instance : new Listener());
  
    if (instance != null) {
        this.withAllowedRoutes(instance.getAllowedRoutes());
        this.withHostname(instance.getHostname());
        this.withName(instance.getName());
        this.withPort(instance.getPort());
        this.withProtocol(instance.getProtocol());
        this.withTls(instance.getTls());
        this.withAllowedRoutes(instance.getAllowedRoutes());
        this.withHostname(instance.getHostname());
        this.withName(instance.getName());
        this.withPort(instance.getPort());
        this.withProtocol(instance.getProtocol());
        this.withTls(instance.getTls());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public AllowedRoutes buildAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  
  public A withAllowedRoutes(AllowedRoutes allowedRoutes) {
    _visitables.get("allowedRoutes").remove(this.allowedRoutes);
    if (allowedRoutes!=null){ this.allowedRoutes= new AllowedRoutesBuilder(allowedRoutes); _visitables.get("allowedRoutes").add(this.allowedRoutes);} else { this.allowedRoutes = null; _visitables.get("allowedRoutes").remove(this.allowedRoutes); } return (A) this;
  }
  
  public boolean hasAllowedRoutes() {
    return this.allowedRoutes != null;
  }
  
  public AllowedRoutesNested<A> withNewAllowedRoutes() {
    return new AllowedRoutesNested(null);
  }
  
  public AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item) {
    return new AllowedRoutesNested(item);
  }
  
  public AllowedRoutesNested<A> editAllowedRoutes() {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(null));
  }
  
  public AllowedRoutesNested<A> editOrNewAllowedRoutes() {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(new AllowedRoutesBuilder().build()));
  }
  
  public AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item) {
    return withNewAllowedRoutesLike(java.util.Optional.ofNullable(buildAllowedRoutes()).orElse(item));
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public String getProtocol() {
    return this.protocol;
  }
  
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  
  public GatewayTLSConfig buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  
  public A withTls(GatewayTLSConfig tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new GatewayTLSConfigBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  
  public boolean hasTls() {
    return this.tls != null;
  }
  
  public TlsNested<A> withNewTls() {
    return new TlsNested(null);
  }
  
  public TlsNested<A> withNewTlsLike(GatewayTLSConfig item) {
    return new TlsNested(item);
  }
  
  public TlsNested<A> editTls() {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(null));
  }
  
  public TlsNested<A> editOrNewTls() {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(new GatewayTLSConfigBuilder().build()));
  }
  
  public TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item) {
    return withNewTlsLike(java.util.Optional.ofNullable(buildTls()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ListenerFluent that = (ListenerFluent) o;
    if (!java.util.Objects.equals(allowedRoutes, that.allowedRoutes)) return false;
  
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    if (!java.util.Objects.equals(protocol, that.protocol)) return false;
  
    if (!java.util.Objects.equals(tls, that.tls)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(allowedRoutes,  hostname,  name,  port,  protocol,  tls,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedRoutes != null) { sb.append("allowedRoutes:"); sb.append(allowedRoutes + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AllowedRoutesNested<N> extends AllowedRoutesFluent<AllowedRoutesNested<N>> implements Nested<N>{
    AllowedRoutesNested(AllowedRoutes item) {
      this.builder = new AllowedRoutesBuilder(this, item);
    }
    AllowedRoutesBuilder builder;
    
    public N and() {
      return (N) ListenerFluent.this.withAllowedRoutes(builder.build());
    }
    
    public N endAllowedRoutes() {
      return and();
    }
    
  
  }
  public class TlsNested<N> extends GatewayTLSConfigFluent<TlsNested<N>> implements Nested<N>{
    TlsNested(GatewayTLSConfig item) {
      this.builder = new GatewayTLSConfigBuilder(this, item);
    }
    GatewayTLSConfigBuilder builder;
    
    public N and() {
      return (N) ListenerFluent.this.withTls(builder.build());
    }
    
    public N endTls() {
      return and();
    }
    
  
  }

}
